@@ -44,7 +44,7 @@
 #include <sys/wait.h>
 #include <unistd.h>
 #include <signal.h>
-#include <libgnome-desktop/gnome-desktop-thumbnail.h>
+#include <libcinnamon-desktop/gnome-desktop-thumbnail.h>
 
 #include "nemo-file-private.h"
 
@@ -440,8 +440,6 @@ thumbnail_thread_notify_file_changed (gpointer image_uri)
 {
 	NemoFile *file;
 
-	gdk_threads_enter ();
-
 	file = nemo_file_get_by_uri ((char *) image_uri);
 #ifdef DEBUG_THUMBNAILS
 	g_message ("(Thumbnail Thread) Notifying file changed file:%p uri: %s\n", file, (char*) image_uri);
@@ -452,12 +450,11 @@ thumbnail_thread_notify_file_changed (gpointer image_uri)
 		nemo_file_invalidate_attributes (file,
 						     NEMO_FILE_ATTRIBUTE_THUMBNAIL |
 						     NEMO_FILE_ATTRIBUTE_INFO);
+        nemo_file_increment_thumbnail_try_count (file);
 		nemo_file_unref (file);
 	}
 	g_free (image_uri);
 
-	gdk_threads_leave ();
-
 	return FALSE;
 }
 
